@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2018 Canonical Ltd.
+ * Copyright (C) 2014-2019 Canonical Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -421,7 +421,7 @@ err:
 	if (!tni)
 		return tty;
 
-	(void)strncpy(tni->tty_name, tty, sizeof(tni->tty_name) - 1);
+	(void)strncpy(tni->tty_name, tty, sizeof(tni->tty_name));
 	tni->dev = dev;
 	tni->next = tty_name_info[hash];
 	tty_name_info[hash] = tni;
